##  Combining Filters with AND, OR, and IS NOT Logic
You can fine-tune your search results using filters with AND, OR, and IS NOT logic. These filters help you include or exclude specific fact sheets, tags, and other criteria. Here's how each operator works:
  * OR: Shows results that match at least one of the selected items.
  * AND: Shows results that match all of the selected items.
  * IS NOT: Excludes results that match any of the selected items. This is helpful for inverting the applied filters to have a list of all fact sheets not related to the applied filters.


You can select these options in the filter group settings by clicking the gear icon in either the filter panel or the filter bar.
![Combining Filters with AND, OR, and NONE Logic](https://help.sap.com/doc/72d375467c1e4dcb872dfa2998b6328d/CLOUD/en-US/loio2754412c7a441014aacef867d1d73ef6_LowRes.png)
Combining Filters with AND, OR, and NONE Logic
